ProSHADE: Class Members

| ProSHADE 0.7.5.1 (JAN 2021) Protein Shape Detection

Here is a list of all documented class members with links to the class documentation for each member:

### - c -

- cAngle : ProSHADE_internal_data::ProSHADE_data
- centreMapOnCOM() : ProSHADE_internal_data::ProSHADE_data
- changeMapResolution : ProSHADE_settings
- changeMapResolutionTriLinear : ProSHADE_settings
- checkIfPeakBelongs() : ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup
- computeCornerPositions() : ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup
- computeEnergyLevelsDesc : ProSHADE_settings
- computeGroupElementsForGroup() : ProSHADE_internal_data::ProSHADE_data
- computeOptimalTranslation() : ProSHADE_internal_data::ProSHADE_data
- computePdbRotationCentre() : ProSHADE_internal_data::ProSHADE_data
- computeRotatedSH() : ProSHADE_internal_data::ProSHADE_data
- computeRotationFuncDesc : ProSHADE_settings
- computeRotationFunction() : ProSHADE_internal_data::ProSHADE_data
- computeRRPMatrices() : ProSHADE_internal_data::ProSHADE_data
- computeSphericalHarmonics() : ProSHADE_internal_data::ProSHADE_data
- computeTraceSigmaDesc : ProSHADE_settings
- computeTranslationMap() : ProSHADE_internal_data::ProSHADE_data
- convertRotationFunction() : ProSHADE_internal_data::ProSHADE_data
- correlationKernel : ProSHADE_settings
- createNewMapFromBounds() : ProSHADE_internal_data::ProSHADE_data